/*
    w32loader
    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef __AFXRES_H__
#define __AFXRES_H__


#include "windows.h"
#include "commctrl.h"


G_BEGIN_DECLS


#ifndef IDC_STATIC
# define IDC_STATIC (-1)
#endif /* not IDC_STATIC */


G_END_DECLS


#endif /* __AFXRES_H__ */
